[![Language grade: Python](https://img.shields.io/lgtm/grade/python/g/gustavopinho/api-lomadee-v3.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/gustavopinho/api-lomadee-v3/context:python)
[![Total alerts](https://img.shields.io/lgtm/alerts/g/gustavopinho/api-lomadee-v3.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/gustavopinho/api-lomadee-v3/alerts/)

# lomadeepy
Implementação não oficial da Api de ofertas lomadee.

- *Ofertas*
- *Categorias*
- *Lojas*
- *Cupons*
- *DeepLink*